#include <wchar.h>

#define MAXMOTS 100000 
#define MAXLETTRE 6 	// mots de 6 lettres  
#define MAXLEN (MAXLETTRE+2)

// Certaines variables sont de portées globales en attendant de connaitre le passage des paramètres par adresse.
// Sera vu en détail en CS221  
/**
 * \brief dictionnaire tableaux de MAXMOTS éléments de type chaine de maximum MAXLEN caractères. (variable globale) 
 */
extern char dictionnaire[MAXMOTS][MAXLEN]; 
/**
 * \brief le nombre de mots enregistrés dans le dictionnaire. (variable globale) 
 */
extern int nbMots; 
/**
 * \brief le mot entré en proposition. (variable globale) 
 */
extern char mot[MAXLEN]; 
/**
 * \brief status un tableau de MAXLETTRE représentant le status de chaque lettre du mot proposé. (variable globale)
 * 
 * Valeur 0 si la letre est non présente 
 * Valeur 1 si la lettre est présente et bien placée, sinon  
 * Valeur 2 si la lettre est présente mais mal placée 
 * pour comprendre le fonctionnement du jeu et plus d'exemples : https://motus.absolu-puzzle.com/
 * 
 * exemple: 	reference 	VIVIER	
 * 		proposition 	VERDIE
 *				122020
 * 
 * 				VENDRE
 * 				120020
*/
extern int statut[MAXLETTRE]; 

/** 
\fn int normaliseMot(char mot[])
* met en majuscule le mot, considéré uniquement de caractères latins hors \0
*/
void normaliseMot(char mot[]); 

/** 
\fn int chercheMot(char mot[],int nbMots)
* \brief Fonction de recherche d'un mot dans le dictionnaire parmis les nbMots.  
*   
* \param mot est une chaine de MAXLETTRE caractères à vérifier .  
* \param nbMots le nombre de mots du dictionnaire
* \return 1 si le mot est trouvé dans le dictionnaire, 0 sinon. (type int) 
*/
int chercheMot(char mot[],int nbMots); 

/** 
\fn int chargeMots(char chemin[])
* \brief Fonction de chargement du dictionnaire à partir d'un fichier. 
* 
* Spécifications: Le fichier contient un mot par ligne.  
* Une ligne peut être un commentaire (ne contient pas de mot) si le premier caractère de la ligne est '#' 
* Charge dans dictionnaire les mots du fichier dans l'ordre du fichier. 
*   
* \param chemin est une chaine de caractères représentant le chemin du fichier de mots.  
* \return le nombre de mots valides stockés dans dictionnaire, -1 si erreur.  
*/

int chargeMots(char chemin[]); 

/** 
\fn int lireMot()
 * \brief Cette fonction gère les caractères entrés (avec la fonction fgets()) par l'utilisateur
 *  
 * Stocke le mot lu (et mis en majuscule si besoin) dans char mot[MAXLEN] en enlevant le \n final (variable globale) 
 * \return retourne 1 si le mot est conforme (estMotValide), 0 sinon 
*/ 
int lireMot(); 

/** 
\fn int verifieMot()
 * \brief Cette fonction compare le mot entré en proposition avec la référence et modifie le tableau statut en fonction.  
 *  
 * \param proposition chaîne de caractères entrée par l'utilisateur 
 * \param reference chaîne de caractères à trouver
 * \return 1 si le mot est découvert entierement, 0 sinon. 
*/ 
int verifieMot(char proposition[],char reference[]); 

/** 
\fn int afficheMot()
 * \brief Cette afffiche les caractères du mot entré en fonction de son statut.
 *  
 * \param proposition chaîne de caractères entrée par l'utilisateur 
*/ 
void afficheMot(char proposition[]); 


void imprime_dico(int nblignes);
